@@ -11,7 +11,7 @@ use Scalar::Util qw( looks_like_number );
 
 use Git::Repository::Command;
 
-our $VERSION = '1.28';
+our $VERSION = '1.300';
 
 # a few simple accessors
 for my $attr (qw( git_dir work_tree options )) {
@@ -67,8 +67,13 @@ sub new {
     my $self = bless {}, $class;
 
     # take out the option hash
-    my %arg = grep { !( ref eq 'HASH' ? $self->{options} ||= $_ : 0 ) } @arg;
-    my $options = $self->{options} ||= {};
+    my ( $options, %arg );
+    {
+        my @o;
+        %arg = grep !( ref eq 'HASH' ? push @o, $_ : 0 ), @arg;
+        croak "Too many option hashes given: @o" if @o > 1;
+        $options = $self->{options} = shift @o || {};
+    }
 
     # ignore 'input' option during object creation
     my $input = delete $options->{input};
@@ -193,13 +198,17 @@ sub command {
 sub run {
     my ( $self, @cmd ) = @_;
 
+    # split the args to get the optional callbacks
+    my @c;
+    @cmd = grep { ref eq 'CODE' ? !push @c, $_ : 1 } @cmd;
+
     # run the command (pass the instance if called as an instance method)
     my $command
         = Git::Repository::Command->new( ref $self ? $self : (), @cmd );
 
     # return the output or die
     local $Carp::CarpLevel = 1;
-    return $command->final_output;
+    return $command->final_output(@c);
 }
 
 #
@@ -324,7 +333,12 @@ Git::Repository - Perl interface to Git repositories
     # - get the full output as a list of lines (no errput)
     @output = $r->run(@cmd);
 
+    # - process the output with callbacks
+    $output = $r->run( @cmd, sub {...} );
+    @output = $r->run( @cmd, sub {...} );
+
     # - obtain a Git::Repository::Command object
+    #   (see Git::Repository::Command for details)
     $cmd = $r->command(@cmd);
 
     # obtain version information
@@ -468,6 +482,11 @@ or as a list of lines in list context. Also accepts a hashref of options.
 
 Lines are automatically C<chomp>ed.
 
+In addition to the options hashref supported by L<Git::Repository::Command>,
+the parameter list can also contain code references, that will be applied
+successively to each line of output. The line being processed is in C<$_>,
+but the coderef must still return the result string (like C<map>).
+
 If the git command printed anything on stderr, it will be printed as
 warnings. If the git sub-process exited with status C<128> (fatal error),
 or C<129> (usage message), C<run()> will C<die()>.
