@@ -4,12 +4,13 @@ use strict;
 use warnings;
 use 5.006;
 use Carp;
+use Scalar::Util qw( blessed );
 
 use Git::Repository;
 use Git::Repository::Command;
 use Git::Repository::Log;
 
-our $VERSION = '1.00';
+our $VERSION = '1.04';
 
 sub new {
     my ( $class, @cmd ) = @_;
@@ -24,6 +25,11 @@ sub new {
         . 'Use run( log => ... ) to parse the output yourself'
         if @badopts;
 
+    # note: there is no --color option to git log  before 1.5.3.3
+    my ($r) = grep blessed $_ && $_->isa('Git::Repository'), @cmd;
+    $r ||= 'Git::Repository';    # no Git::Repository object given
+    unshift @cmd, '--no-color' if $r->version_ge('1.5.3.3');
+
     # enforce the format
     @cmd = ( 'log', '--pretty=raw', @cmd );
 
@@ -46,9 +52,10 @@ sub next {
     }
 
     # EOF
-    return if !@records;
+    return $self->{cmd}->final_output() if !@records;
 
     # the first two records are always the same, with --pretty=raw
+    local $/ = "\n";
     my ( $header, $message, $extra ) = ( @records, '' );
     my @headers = map { chomp; split / /, $_, 2 } split /^/m, $header;
     chomp( $message, $extra ) if exists $self->{record};
@@ -86,9 +93,9 @@ Git::Repository::Log::Iterator - Split a git log stream into records
 
 =head1 DESCRIPTION
 
-C<Git::Repository::Log::Iterator> initiates a B<git log> command
+L<Git::Repository::Log::Iterator> initiates a B<git log> command
 from a list of paramaters and parses its output to produce
-C<Git::Repository::Log> objects represening each log item.
+L<Git::Repository::Log> objects represening each log item.
 
 =head1 METHODS
 
@@ -98,12 +105,13 @@ Create a new B<git log> stream from the parameter list in C<@args>
 and return a iterator on it.
 
 C<new()> will happily accept any parameters, but note that
-C<Git::Repository::Log::Iterator> expects the output to look like that
+L<Git::Repository::Log::Iterator> expects the output to look like that
 of C<--pretty=raw>, and so will force the the C<--pretty> option
 (in case C<format.pretty> is defined in the Git configuration).
+It will also forcibly remove colored output (using C<--color=never>).
 
-Extra ouput (like patches) will be stored in the C<extra> parameter of
-the C<Git::Repository::Log> object. Decorations will be lost.
+Extra output (like patches) will be stored in the C<extra> parameter of
+the L<Git::Repository::Log> object. Decorations will be lost.
 
 When unsupported options are recognized in the parameter list, C<new()>
 will C<croak()> with a message advising to use C<< run( 'log' => ... ) >>
@@ -111,7 +119,7 @@ to parse the output yourself.
 
 =head2 next()
 
-Return the next log item as a C<Git::Repository::Log> object,
+Return the next log item as a L<Git::Repository::Log> object,
 or nothing if the stream has ended.
 
 =head1 AUTHOR
